==> qtjambi-activex-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiActiveX/QAxObject_shell.h <==
#ifndef QAXOBJECT_SHELL_H
#define QAXOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <ActiveQt/qaxobject.h>
#include <QtJambi/QtJambiAPI>
#include <ActiveQt/qaxbase.h>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAxObject_shell : public QAxObject, public QtJambiShellInterface
{
public:
    QAxObject_shell(QObject* parent0 = nullptr);
    QAxObject_shell(const QString& c0, QObject* parent1 = nullptr);
    ~QAxObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    ulong classContext() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString control() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool propertyWritable(const char* arg__1) const override;
    void resetControl() override;
    void setClassContext(ulong classContext0) override;
    bool setControl(const QString& c0) override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxObject_access : public QAxObject
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_classContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
    jstring __qt_control(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    void __qt_resetControl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setClassContext_ulong(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint classContext0);
    jboolean __qt_setControl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring c0);
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
};

#endif // QAXOBJECT_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiActiveX/QAxObject_shell.h <==
#ifndef QAXOBJECT_SHELL_H
#define QAXOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxObject_shell : public QAxObject, public QtJambiShellInterface
{
public:
    QAxObject_shell(QObject* parent0 = nullptr);
    QAxObject_shell(const QString& c0, QObject* parent1 = nullptr);
    ~QAxObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    ulong classContext() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString control() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool propertyWritable(const char* arg__1) const override;
    void resetControl() override;
    void setClassContext(ulong classContext0) override;
    bool setControl(const QString& c0) override;
    void setPropertyWritable(const char* arg__1, bool arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxObject_access : public QAxObject
{
    static jobject __qt_argumentsToList_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(JNIEnv *__jni_env, jobject var10, jobject var21, jobject var32, jobject var43, jobject var54, jobject var65, jobject var76, jobject var87);
    void __qt_connectNotify(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dynamicCall_const_char_ptr_ref_QList_unsigned(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject vars1, jint flags2);
    jint __qt_indexOfVerb_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring verb0) const;
    void __qt_initializeFrom_QAxBase_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID that0);
    void __qt_internalRelease(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_classContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
    jstring __qt_control(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_propertyWritable_const_char_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1) const;
    void __qt_resetControl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setClassContext_ulong(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint classContext0);
    jboolean __qt_setControl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring c0);
    void __qt_setPropertyWritable_const_char_ptr_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1, jboolean arg__2);
};

#endif // defined(Q_OS_WIN)
#endif // QAXOBJECT_SHELL_H
